@@ -3,7 +3,7 @@ package oEdtk::AddrField;
 use strict;
 use warnings;
 
-use oEdtk::Main qw(maj_sans_accents);
+use oEdtk::Main qw(oe_uc_sans_accents);
 use base 'oEdtk::Field';
 our $VERSION		= 0.01;
 
@@ -12,7 +12,7 @@ sub process {
 
 	$data =~ s/^\s+//;
 	$data =~ s/\s+$//;
-	maj_sans_accents($data);
+	oe_uc_sans_accents($data);
 	return uc($data);
 }
 
