@@ -8,8 +8,10 @@ use oEdtk::Config	qw(config_read);
 use oEdtk::DBAdmin	qw(db_connect);
 use oEdtk::Outmngr	qw(omgr_depot_poste);
 
-if (@ARGV < 2) {
-	die "Usage: $0 <idldoc> <yyyymmdd>\n\n or for a range of values $0 <nnn%> <yyyymmdd>\n";
+if (@ARGV < 2 or $ARGV[0] =~/-h/i) {
+	warn "Usage: $0 <idldoc> <yyyymmdd>\n\n or for a range of values $0 <nnn%> <yyyymmdd>\n\n";
+	warn "\tThis loads post date for idldoc.\n";
+	exit 1;
 }
 
 
